@@ -9,7 +9,7 @@ use Carp;
 
 use constant HOSTNAME => hostname();
 
-$Net::Server::Mail::VERSION = '0.18';
+$Net::Server::Mail::VERSION = '0.19';
 
 =pod
 
@@ -727,13 +727,13 @@ Olivier Poitrey E<lt>rs@rhapsodyk.netE<gt>
 
 Available on CPAN.
 
-anonymous SVN repository:
+anonymous Git repository:
 
-svn co https://emailproject.perl.org/svn/Net-Server-Mail
+git clone git://github.com/rs/net-server-mail.git
 
-SVN repository on the web:
+Git repository on the web:
 
-http://emailproject.perl.org/svn/Net-Server-Mail/
+L<https://github.com/rs/net-server-mail>
 
 =head1 BUGS
 
